pub struct UpdatePackageDetails {
pub scheduled_package_id: Box<ScheduledPackageId>,
pub package_time_slot: Box<TimeSlot>,
}Expand description
UpdatePackageDetails : Request to update the time slot of a package.
Fields
scheduled_package_id: Box<ScheduledPackageId>package_time_slot: Box<TimeSlot>Implementations
sourceimpl UpdatePackageDetails
impl UpdatePackageDetails
sourcepub fn new(
scheduled_package_id: ScheduledPackageId,
package_time_slot: TimeSlot
) -> UpdatePackageDetails
pub fn new(
scheduled_package_id: ScheduledPackageId,
package_time_slot: TimeSlot
) -> UpdatePackageDetails
Request to update the time slot of a package.